@@ -22,7 +22,7 @@ from .ParameterStructure.Assets import ContainedResourceFileEntry
 from .ParameterStructure.SimObjects import SimId
 
 from .config import continue_on_error
-from .utils import sort_references, sort_component_list, parse_slot
+from .utils import sort_references, sort_component_list, sort_slots, parse_slot
 from .simultan_utils import create_parameter
 from . import create_component
 from .slots import SimSlotBase
@@ -797,6 +797,78 @@ class List(UserList):
 
     _create_all = False     # if true all properties are evaluated to create python objects when initialized
 
+    def __init__(self, *args, **kwargs):
+        self._wrapped_obj = kwargs.get('wrapped_obj', None)
+        self._contained_components = kwargs.get('contained_components', None)
+        self._contained_parameters = kwargs.get('contained_parameters', None)
+        self._template_parser = kwargs.get('template_parser', None)
+        self._data_model_id = kwargs.get('data_model_id', None)
+
+        # if self._create_all:
+        #     _ = self.contained_components
+        #     _ = self.contained_parameters
+
+    @property
+    def data(self):
+        if self._wrapped_obj is None:
+            return
+        components = [x.Component for x in self._wrapped_obj.Components.Items]
+        ref_components = [x.Target for x in self._wrapped_obj.ReferencedComponents.Items]
+        all_components = [*components, *ref_components]
+
+        slots = [*[x.Slot for x in self._wrapped_obj.Components.Items],
+                 *[x.Slot for x in self._wrapped_obj.ReferencedComponents.Items]]
+
+        try:
+            indices = sort_slots(slots)
+            return [x for _, x in sorted(zip(indices, all_components))]
+        except TypeError as e:
+            logger.warning(f'Could not sort list {all_components}:\n{e}')
+            return all_components
+
+    def __getitem__(self, i):
+        if isinstance(i, slice):
+            if self._template_parser is None:
+                return self.__class__(self.data[i])
+            return [self._template_parser.create_python_object(x) for x in self.__class__(self.data[i])]
+        else:
+            if self._template_parser is None:
+                return self.data[i]
+            return self._template_parser.create_python_object(self.data[i])
+
+    def __repr__(self):
+        return f'{self.name}: ' + repr(list(self.data))
+
+    @property
+    def contained_components(self):
+        if self._contained_components is None:
+            if self._wrapped_obj is not None:
+                self._contained_components = [self._template_parser.create_python_object(x.Component) for x in self._wrapped_obj.Components.Items]
+        return self._contained_components
+
+    @property
+    def contained_parameters(self):
+        if self._contained_parameters is None:
+            if self._wrapped_obj is not None:
+                self._contained_parameters = {x.Name: x.get_ValueCurrent() for x in self._wrapped_obj.Parameters.Items}
+        return self._contained_parameters
+
+    @property
+    def name(self):
+        if self._wrapped_obj is not None:
+            if hasattr(self._wrapped_obj, 'Name'):
+                return self._wrapped_obj.Name
+
+    @name.setter
+    def name(self, value):
+        if self._wrapped_obj is not None:
+            self._wrapped_obj.Name = value
+
+
+class ComponentList(UserList):
+
+    _create_all = False  # if true all properties are evaluated to create python objects when initialized
+
     def __init__(self, *args, **kwargs):
         self._wrapped_obj = kwargs.get('wrapped_obj', None)
         self._contained_components = kwargs.get('contained_components', None)
@@ -837,7 +909,8 @@ class List(UserList):
     def contained_components(self):
         if self._contained_components is None:
             if self._wrapped_obj is not None:
-                self._contained_components = [self._template_parser.create_python_object(x.Component) for x in self._wrapped_obj.Components.Items]
+                self._contained_components = [self._template_parser.create_python_object(x.Component) for x in
+                                              self._wrapped_obj.Components.Items]
         return self._contained_components
 
     @property
